<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nb_NO">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../about.ui" line="33"/>
        <source>&amp;Info</source>
        <translation>&amp;Info</translation>
    </message>
    <message>
        <location filename="../about.ui" line="89"/>
        <source>&amp;Translators</source>
        <translation>&amp;Oversettere</translation>
    </message>
    <message>
        <location filename="../about.ui" line="145"/>
        <source>&amp;License</source>
        <translation>&amp;Lisenser</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation>&amp;YouTube%1-leser for SMPlayer</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="37"/>
        <source>Version: %1</source>
        <translation>Versjon: %1</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="39"/>
        <source>Portable Edition</source>
        <translation>Flyttbar utgave</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Compiled with Qt %1 (using %2)</source>
        <translation>Kompilert med QT %1 (bruker Qt %2)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Visit our website for updates:</source>
        <translation>Besøk vår nettside for oppdateringer:</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="87"/>
        <source>Many people contributed with translations.</source>
        <translation>Mange personer bidro med oversettelser.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="88"/>
        <source>You can also help to translate SMTube into your own language.</source>
        <translation>Du kan også hjelpe med å oversette SMTube til ditt eget språk.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="89"/>
        <source>Visit %1 and join a translation team.</source>
        <translation>Besøk %1 og bli med på et oversetterlag.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="91"/>
        <source>Click here to know the translators from the transifex teams</source>
        <translation>Klikk her for å se oversetterne fra Transifex-lagene</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="117"/>
        <source>&lt;b&gt;%1&lt;/b&gt; (%2)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; (%2)</translation>
    </message>
</context>
<context>
    <name>BrowserWindow</name>
    <message>
        <location filename="../browserwindow.cpp" line="112"/>
        <source>Home</source>
        <translation>Hjem</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="115"/>
        <source>Navigation</source>
        <translation>Navigasjon</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="123"/>
        <source>Zoom +</source>
        <translation>Zoom +</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="127"/>
        <source>Zoom -</source>
        <translation>Zoom -</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="131"/>
        <source>&amp;Quit</source>
        <translation>&amp;Avslutt</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="134"/>
        <source>&amp;Navigation</source>
        <translation>&amp;Navigasjon</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="146"/>
        <source>&amp;View</source>
        <translation>&amp;Vis</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="147"/>
        <source>Toolbar</source>
        <translation>Verktøylinje</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="151"/>
        <source>Statusbar</source>
        <translation>Statuslinje</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="155"/>
        <source>&amp;Settings</source>
        <translation>&amp;Innstillinger</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="163"/>
        <source>&amp;Help</source>
        <translation>&amp;Hjelp</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="167"/>
        <source>&amp;Update YouTube playback support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="169"/>
        <source>&amp;Install / Update YouTube playback support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="175"/>
        <source>&amp;About SMTube</source>
        <translation>&amp;Om SMTube</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="296"/>
        <source>Download video using an external service</source>
        <translation>Last ned videoen ved hjelp av en ekstern tjeneste</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="297"/>
        <source>Download</source>
        <translation>Last ned</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="524"/>
        <source>No video found</source>
        <translation>Ingen video ble funnet</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="525"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation>Det var ikke mulig å finne nettadressen til denne videoen.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="282"/>
        <source>Loading... %1%</source>
        <translation>&amp;Laster inn... %1%</translation>
    </message>
</context>
<context>
    <name>CodeDownloader</name>
    <message>
        <location filename="../codedownloader.cpp" line="49"/>
        <source>Downloading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="76"/>
        <source>Connecting to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="145"/>
        <source>The YouTube code has been installed successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="146"/>
        <source>Installed version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="147"/>
        <source>Success</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="152"/>
        <location filename="../codedownloader.cpp" line="157"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="152"/>
        <source>It&apos;s not possible to save %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="157"/>
        <source>An error happened while downloading the file:&lt;br&gt;%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="165"/>
        <source>%1 failed to communicate with youtube-dl. Either it&apos;s not installed or it doesn&apos;t work correctly.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="169"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation type="unfinished">Det var ikke mulig å finne nettadressen til denne videoen.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="170"/>
        <source>Maybe you need to update youtube-dl.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="175"/>
        <location filename="../codedownloader.cpp" line="208"/>
        <source>In order to play YouTube videos, %1 needs an external application called youtube-dl.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="176"/>
        <source>This component needs to be updated frequently.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="177"/>
        <source>You can update it just by reinstalling SMPlayer. The installer will download and install the very latest version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="179"/>
        <source>Install / Update YouTube support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="209"/>
        <source>%1 can download and install this application for you.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="210"/>
        <source>It will be downloaded from the official website and installed in %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="211"/>
        <source>Would you like to proceeed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="215"/>
        <location filename="../codedownloader.cpp" line="218"/>
        <source>Install YouTube support?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog.ui" line="14"/>
        <source>Settings</source>
        <translation>Innstillinger</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="27"/>
        <source>&amp;General</source>
        <translation>&amp;Generelt</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="127"/>
        <source>A&amp;dd...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="166"/>
        <source>&amp;Players</source>
        <translation>&amp;Avspillere</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="214"/>
        <source>Add</source>
        <translation>Legg til</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="179"/>
        <source>Up</source>
        <translation>Opp</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="33"/>
        <source>Playback</source>
        <translation>Avspilling</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="39"/>
        <source>Preferred &amp;quality:</source>
        <translation>Foretrukket &amp;kvalitet:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="94"/>
        <source>Sites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="100"/>
        <source>&amp;Site:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="120"/>
        <source>Edi&amp;t...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="138"/>
        <source>De&amp;lete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="225"/>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="249"/>
        <source>Edit</source>
        <translation>Rediger</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="262"/>
        <source>A&amp;dd predefined players</source>
        <translation>L&amp;egg til forhåndsdefinerte avspillere</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="298"/>
        <source>&amp;Interface</source>
        <translation>&amp;Grensesnitt</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="306"/>
        <source>&amp;Style:</source>
        <translation>&amp;Stil:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="342"/>
        <source>Font:</source>
        <translation>Font:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="356"/>
        <source>C&amp;hange...</source>
        <translation>E&amp;ndre...</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="68"/>
        <source>Download</source>
        <translation>Last ned</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="74"/>
        <source>Download videos using an &amp;external service</source>
        <translation>Last ned videoener ved hjelp av en &amp;ekstern tjeneste</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="190"/>
        <source>Down</source>
        <translation>Ned</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="79"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <location filename="../filechooser.cpp" line="56"/>
        <source>Click to select a file or folder</source>
        <translation>Klikk for å velge en fil eller mappe</translation>
    </message>
</context>
<context>
    <name>MyWebView</name>
    <message>
        <location filename="../mywebview.cpp" line="37"/>
        <source>Open in &amp;YouTube</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="48"/>
        <source>&amp;Save link...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="51"/>
        <source>Copy &amp;link to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="52"/>
        <source>Open link in this window</source>
        <translation>Åpne en lenke i dette vinduet</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="54"/>
        <source>&amp;Copy text to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="55"/>
        <source>Open link in &amp;new window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="79"/>
        <source>&amp;Play with</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="84"/>
        <source>Play &amp;audio with</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="137"/>
        <source>&amp;Play with %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="144"/>
        <source>Play &amp;audio with %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="151"/>
        <source>Play video with a &amp;web browser</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlayerDialog</name>
    <message>
        <location filename="../playerdialog.ui" line="14"/>
        <source>Edit Player</source>
        <translation>Rediger tekst til spiller</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation>&amp;Navn:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="39"/>
        <source>&amp;Executable:</source>
        <translation>&amp;Eksekverbar fil:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="56"/>
        <source>&amp;Parameters:</source>
        <translation>&amp;Parametere:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="71"/>
        <source>This player supports &amp;video sites</source>
        <translation>Denne avspillerene støtter &amp;videosider</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="78"/>
        <source>This player can play &amp;online TV</source>
        <translation>Denne avspilleren kan spille av online-TV</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="87"/>
        <source>Preferred &amp;quality:</source>
        <translation>Foretrukket &amp;kvalitet:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="117"/>
        <source>Add to &amp;menu:</source>
        <translation>Legg til &amp;i meny:</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="28"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="29"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="30"/>
        <source>Audio</source>
        <translation>Lyd</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="31"/>
        <source>Video and audio</source>
        <translation>Video- og lyd-filer</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="33"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
</context>
<context>
    <name>SiteDialog</name>
    <message>
        <location filename="../sitedialog.ui" line="14"/>
        <source>Edit Site</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation type="unfinished">&amp;Navn:</translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="39"/>
        <source>&amp;Home page URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="56"/>
        <source>&amp;Search URL:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
